package javax.swing;

import javax.accessibility.AccessibleRole;
import javax.accessibility.AccessibleContext;
import java.io.IOException;
import java.io.ObjectOutputStream;
import javax.accessibility.Accessible;

public class JRadioButtonMenuItem extends JMenuItem implements Accessible
{
    private static final String uiClassID = "RadioButtonMenuItemUI";
    
    public JRadioButtonMenuItem() {
        this(null, null, false);
    }
    
    public JRadioButtonMenuItem(Icon icon) {
        this(null, icon, false);
    }
    
    public JRadioButtonMenuItem(String s) {
        this(s, null, false);
    }
    
    public JRadioButtonMenuItem(Action action) {
        this();
        this.setAction(action);
    }
    
    public JRadioButtonMenuItem(String s, Icon icon) {
        this(s, icon, false);
    }
    
    public JRadioButtonMenuItem(String s, boolean selected) {
        this(s);
        this.setSelected(selected);
    }
    
    public JRadioButtonMenuItem(Icon icon, boolean b) {
        this(null, icon, b);
    }
    
    public JRadioButtonMenuItem(String s, Icon icon, boolean selected) {
        super(s, icon);
        this.setModel(new JToggleButton.ToggleButtonModel());
        this.setSelected(selected);
        this.setFocusable(false);
    }
    
    @Override
    public String getUIClassID() {
        return "RadioButtonMenuItemUI";
    }
    
    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        objectOutputStream.defaultWriteObject();
        if (this.getUIClassID().equals("RadioButtonMenuItemUI")) {
            int n = (byte)(JComponent.getWriteObjCounter(this) - 1);
            JComponent.setWriteObjCounter(this, (byte)n);
            if (n == 0 && this.ui != null) {
                this.ui.installUI(this);
            }
        }
    }
    
    @Override
    protected String paramString() {
        return super.paramString();
    }
    
    @Override
    boolean shouldUpdateSelectedStateFromAction() {
        return true;
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new JRadioButtonMenuItem.AccessibleJRadioButtonMenuItem();
        }
        return this.accessibleContext;
    }
    
    protected class AccessibleJRadioButtonMenuItem extends JMenuItem.AccessibleJMenuItem
    {
        @Override
        public AccessibleRole getAccessibleRole() {
            return AccessibleRole.RADIO_BUTTON;
        }
    }
}
